==> onecx-permissions-client-0.28.0-sources.jar: gen/org/tkit/onecx/permission/model/PermissionRequest.java <==
package gen.org.tkit.onecx.permission.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import java.lang.reflect.Type;
import com.fasterxml.jackson.annotation.JsonProperty;

@JsonIgnoreProperties(ignoreUnknown = true)
@io.quarkus.runtime.annotations.RegisterForReflection
public class PermissionRequest  {

    private String token;

    /**
    * Get token
    * @return token
    **/
    @JsonProperty("token")
    public String getToken() {
        return token;
    }

    /**
     * Set token
     **/
    public void setToken(String token) {
        this.token = token;
    }

    public PermissionRequest token(String token) {
        this.token = token;
        return this;
    }

    /**
     * Create a string representation of this pojo.
     **/
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PermissionRequest {\n");

        sb.append("    token: ").append(toIndentedString(token)).append("\n");
        
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private static String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

    @JsonIgnoreProperties(ignoreUnknown = true)
@io.quarkus.runtime.annotations.RegisterForReflection
    public static class PermissionRequestQueryParam  {

        @jakarta.ws.rs.QueryParam("token")
        private String token;

        /**
        * Get token
        * @return token
        **/
        @JsonProperty("token")
        public String getToken() {
            return token;
        }

        /**
         * Set token
         **/
        public void setToken(String token) {
            this.token = token;
        }

        public PermissionRequestQueryParam token(String token) {
            this.token = token;
            return this;
        }

        /**
         * Create a string representation of this pojo.
         **/
        @Override
        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append("class PermissionRequestQueryParam {\n");

            sb.append("    token: ").append(toIndentedString(token)).append("\n");
            sb.append("}");
            return sb.toString();
        }

        /**
         * Convert the given object to string with each line indented by 4 spaces
         * (except the first line).
         */
        private static String toIndentedString(Object o) {
            if (o == null) {
                return "null";
            }
            return o.toString().replace("\n", "\n    ");
        }
    }}

==> onecx-permissions-client-1.7.0-sources.jar: gen/org/tkit/onecx/permission/model/PermissionRequest.java <==
package gen.org.tkit.onecx.permission.model;


import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import com.fasterxml.jackson.annotation.JsonProperty;

@io.quarkus.runtime.annotations.RegisterForReflection
@com.fasterxml.jackson.annotation.JsonIgnoreProperties(ignoreUnknown = true)
public class PermissionRequest  {

    private String token;

    /**
    * Get token
    * @return token
    **/
    @JsonProperty("token")
    public String getToken() {
        return token;
    }

    /**
     * Set token
     **/
    public void setToken(String token) {
        this.token = token;
    }

    public PermissionRequest token(String token) {
        this.token = token;
        return this;
    }

    /**
     * Create a string representation of this pojo.
     **/
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PermissionRequest {\n");

        sb.append("    token: ").append(toIndentedString(token)).append("\n");
        
        sb.append("}");
        return sb.toString();
    }

    /**
     * Compares this object to the specified object. The result is
     * {@code true} if and only if the argument is not
     * {@code null} and is a {@code PermissionRequest} object that
     * contains the same values as this object.
     *
     * @param   obj   the object to compare with.
     * @return  {@code true} if the objects are the same;
     *          {@code false} otherwise.
     **/
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null || getClass() != obj.getClass()) return false;

        PermissionRequest model = (PermissionRequest) obj;

        return java.util.Objects.equals(token, model.token);
    }

    /**
     * Returns a hash code for a {@code PermissionRequest}.
     *
     * @return a hash code value for a {@code PermissionRequest}.
     **/
    @Override
    public int hashCode() {
    return java.util.Objects.hash(token);
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private static String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

    @com.fasterxml.jackson.annotation.JsonIgnoreProperties(ignoreUnknown = true)
@io.quarkus.runtime.annotations.RegisterForReflection
    public static class PermissionRequestQueryParam  {

        @jakarta.ws.rs.QueryParam("token")
        private String token;

        /**
        * Get token
        * @return token
        **/
        @com.fasterxml.jackson.annotation.JsonProperty("token")
        public String getToken() {
            return token;
        }

        /**
         * Set token
         **/
        public void setToken(String token) {
            this.token = token;
        }

        public PermissionRequestQueryParam token(String token) {
            this.token = token;
            return this;
        }

        /**
         * Create a string representation of this pojo.
         **/
        @Override
        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append("class PermissionRequestQueryParam {\n");

            sb.append("    token: ").append(toIndentedString(token)).append("\n");
            sb.append("}");
            return sb.toString();
        }

        /**
         * Convert the given object to string with each line indented by 4 spaces
         * (except the first line).
         */
        private static String toIndentedString(Object o) {
            if (o == null) {
                return "null";
            }
            return o.toString().replace("\n", "\n    ");
        }
    }}
